aboutsummaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorPetr Kraus <petr_kraus@email.cz>2019-08-14 00:54:01 +0200
committerMark Lobodzinski <mark@lunarg.com>2019-08-16 10:09:00 -0600
commit94f8b70b49b1d7e8e10f3c04827bafc7f9d9707c (patch)
tree86c4c49526ea9aae8baa99d8e7693dcdf25d7036 /scripts
parent3c18a6857f0bc151bed9844059f2cd62feb04428 (diff)
downloadvulkan-validation-layers-94f8b70b49b1d7e8e10f3c04827bafc7f9d9707c.tar.gz
ci: Relax summary limit to 64
from 54
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/check_commit_message_format.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/check_commit_message_format.sh b/scripts/check_commit_message_format.sh
index 8bc83830a..4eb5de8b7 100755
--- a/scripts/check_commit_message_format.sh
+++ b/scripts/check_commit_message_format.sh
@@ -55,9 +55,9 @@ printf %s "$COMMIT_TEXT" | while IFS='' read -r line; do
fi
chars=${#line}
if [ $current_line -eq 1 ]; then
- # Subject line should be 50 chars or less (but give some slack here)
- if [ $chars -gt 54 ]; then
- echo "The following subject line exceeds 50 characters in length."
+ # Subject line should be 64 chars or less
+ if [ $chars -gt 64 ]; then
+ echo "The following subject line exceeds 64 characters in length."
echo " '$line'"
success=0
fi